# soinn
This is the repo for python package soinn.

## install
`
pip install soinn
`

## build by hand
`python
python -m build
`

## run demo
After install soinn, you can run a demo to show how soinn works.
`
cd demo && python demo.py
`
You can get the following result
![image](https://github.com/uestc-lfs/soinn/blob/master/demo/result.png)
